import { DesignComp } from "@/modules/editor/defines/DesignTemp/DesignComp";
import FormUI, { ColumnItem } from "@queenjs/components/FormUI";
import { set } from "lodash";
import { defineComponent } from "vue";
import { any } from "vue-types";
import { GroupNumber } from "../formItems/GroupNumber";
import { InputNumber } from "ant-design-vue";

const layoutColumns: ColumnItem[] = [
  {
    label: "尺寸",
    dataIndex: "layout.size",
    component: GroupNumber,
    props: {
      labels: ["宽度", "高度"],
    },
  },
  {
    label: "对齐",
    dataIndex: "layout.textAlign",
    component: "Select",
    props: {
      options: [
        { label: "左对齐", value: "left" },
        { label: "居中", value: "center" },
        { label: "右对齐", value: "right" },
      ],
    },
  },
  {
    label: "左右偏移",
    dataIndex: "layout.offsetX",
    component: "Slider",
    props: {
      min: -375,
      max: 375,
    },
    getValue: (v) => v || 0,
  },
  {
    label: "上下偏移",
    dataIndex: "layout.offsetY",
    component: "Slider",
    props: {
      min: -375,
      max: 375,
    },
    getValue: (v) => v || 0,
  },
  {
    label: "层级",
    dataIndex: "layout.zIndex",
    component: InputNumber,
    props: {
      min: 0,
      max: 99,
    },
  },
];

export function createAttrsForm(valueColumns: ColumnItem[]) {
  return defineComponent({
    props: {
      component: any<DesignComp>().isRequired,
    },
    setup(props) {
      function changeVal(e: { dataIndex: string; value: any }) {
        set(props.component, e.dataIndex, e.value);
      }

      return () => {
        const { component } = props;
        return (
          <div>
            <div>组件布局</div>
            <FormUI
              data={component}
              columns={layoutColumns}
              onChange={changeVal}
            />
            <div>组件属性</div>
            <FormUI
              data={component}
              columns={valueColumns}
              onChange={changeVal}
            />
          </div>
        );
      };
    },
  });
}
